@@ -1,5 +1,5 @@
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "config.h"
 #include "preferencesdialog.h"
@@ -19,7 +19,6 @@ PFile &config = PFile::instance;
 
 PFile::PFile(): 
   ReshapeBoxSize("ReshapeBoxSize", "Size of reshape handles"),
-  ScreenResolution("ScreenResolution", "Screen resolution"),
   DefaultResolution("DefaultResolution", "Default image resolution"),
   ZoomLevel("ZoomLevel", "Default page zoom level"),
   StartPage("StartPage", "Default start page in a new document"),
@@ -43,10 +42,6 @@ PFile::PFile():
   ReshapeBoxSize.visible = false; //Don't show up in preferences dialog
   ReshapeBoxSize.values.push_back(7);
 
-  declare_var(&ScreenResolution);
-  ScreenResolution.visible = false;
-  ScreenResolution.values.push_back(72);
-
   declare_var(&DefaultResolution);
   DefaultResolution.values.push_back(72);
 
