@@ -1,7 +1,7 @@
 #ifndef IMAGEFRAME_H		// -*- c++ -*-
 #define IMAGEFRAME_H
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "util/filewatcher.h"
 #include "cachedframe.h"
@@ -11,11 +11,8 @@ public:
   // try to determine if a file is a ps
   static bool is_postscript(std::string filename);
 
-  ImageFrame(Group *parent, 
-	      const std::string& assoc,
-	      float w, float h);
-  ImageFrame(Group *parent, const xmlpp::Element& node,
-	     const FileContext &context);
+  ImageFrame(Group *parent, const std::string& assoc);
+  ImageFrame(const ElementWrap& xml, Group *parent);
   virtual ~ImageFrame();
 
   virtual std::string getTypeName() const;
@@ -26,12 +23,14 @@ public:
 
 
   // *** undoable actions ***
-  void set_association(const std::string &s, undo::Undoable *history = 0);
+  void set_association(const std::string &s);
 
 
   // *** probe state ***
+  Boundary get_box() const;
   const std::string &get_association() const {return association;}
-
+  Vector get_inherent_size() const { return Vector(width, height); }
+  
 protected:
   std::string association, parsed_file;
   FileWatcher filewatcher;
@@ -39,6 +38,8 @@ protected:
   void generate_picture(FileCallback callback);
   void on_file_modified();
   void read_size();
+private:
+  float width, height;
 };
 
 #endif
