@@ -29,6 +29,9 @@ int main(int argc, char *argv[]) {
     // initialise gtkmm
     Gtk::Main kit(argc, argv);
 
+    // initialize GnomeCanvas
+    Gnome::Canvas::init();
+
     // application icon
     std::vector<Glib::RefPtr<Gdk::Pixbuf> > icon_list;
     icon_list.push_back(Gdk::Pixbuf::create_from_inline(9240, icon_48));
@@ -113,8 +116,3 @@ int main(int argc, char *argv[]) {
     return 1;
   }
 }
-
-
-
-
-
