@@ -1,5 +1,5 @@
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "pagesel.h"
 #include "document/page.h"
@@ -13,20 +13,19 @@
 #include <gtkmm/label.h>
 
 void Pagesel::page_selected_action() {
-  Gtk::Menu *menu;
+  Gtk::Menu *menu = pages.get_menu();
   Gtk::MenuItem *active_item;
-  if((menu = pages.get_menu())
-     && (active_item = menu->get_active())) {
-      if(Gtk::Label *num = 
-	 dynamic_cast<Gtk::Label*>(active_item->get_child())) {
-	DocRef document = document_view.get_document();
-	Page *page;
-	if(document && (page = document->get_page(num->get_text())))
-	  document_view.set_current_page_num(page->get_page_num());
-      } else
-	warning << "Arrggghhh! Not a Gtk::Label!" 
-		<< " Please report this error." << std::endl;
-      //run around in circles and scream!
+  Gtk::Widget *child;
+  Gtk::Label *label;
+  // if active_item->get_child() returns null, then we are probably
+  // try to switch to the same page as we are coming from.
+  if(menu && (active_item = menu->get_active())
+     && (child = active_item->get_child())
+     && (label = dynamic_cast<Gtk::Label*>(child))) {
+    DocRef document = document_view.get_document();
+    Page *page;
+    if(document && (page = document->get_page(label->get_text())))
+      document_view.set_current_page_num(page->get_page_num());
   }
 }
 
@@ -88,6 +87,13 @@ void Pagesel::update() {
   pages.set_menu(menu);
 }
 
+void Pagesel::on_realize() {
+  Gtk::HBox::on_realize();
+  // this fixes a problem with get_active()->get_child in
+  // page_selected_action()
+  update();
+}
+
 Pagesel::Pagesel(DocumentView &docview) :
   document_view(docview)
 {
@@ -134,7 +140,7 @@ namespace {
 }
 
 TemplatePageDialog::TemplatePageDialog(Gtk::Window &parent, 
-					   DocumentView &document_view_):
+                                       DocumentView &document_view_):
   DialogWrap("", parent), 
   document_view(document_view_)
 {
@@ -207,37 +213,35 @@ void TemplatePageDialog::show_it(bool new_page_, int page_num_) {
 }
 
 void TemplatePageDialog::on_response(int response_id) {
-  switch(response_id) {
-  case Gtk::RESPONSE_OK:
-    {
-      DocRef document = document_view.get_document();
-      if(new_page && document) {
-	std::string page_name = "";
-	Glib::RefPtr<Gtk::TreeSelection> selection = page_list.get_selection();
-	Gtk::TreeModel::iterator iter = selection->get_selected();
-	if(iter) {
-	  Gtk::TreeModel::Row row = *iter;
-	  page_name = Glib::ustring(row[columns.col_name]);
-	}
-	
-	  if(!page_name.empty() && page_name != no_template_string
-	     && document->get_template()) {
-	    Page *t_page = document->get_template()->get_page(page_name);
-	    if(!t_page) {
-	      // There should only be existing template pages in the list
-	      throw std::logic_error("Template page \""
-				     + page_name
-				     + "\" not found");
-	      return;
-	    }
-	    document->new_page(page_num, t_page); //problem here
-	  } else
-	    document->new_page(page_num);
+  if(response_id == Gtk::RESPONSE_OK) { // assume anything else means CANCEL
+    DocRef document = document_view.get_document();
+    if(new_page && document) {
+      std::string page_name = "";
+      Glib::RefPtr<Gtk::TreeSelection> selection = page_list.get_selection();
+      Gtk::TreeModel::iterator iter = selection->get_selected();
+      if(iter) {
+        Gtk::TreeModel::Row row = *iter;
+        page_name = Glib::ustring(row[columns.col_name]);
       }
+      
+      if(!page_name.empty() && page_name != no_template_string
+         && document->get_template()) {
+        Page *t_page = document->get_template()->get_page(page_name);
+        if(!t_page) {
+          // There should only be existing template pages in the list
+          throw std::logic_error("Template page \""
+                                 + page_name
+                                 + "\" not found");
+          return;
+        }
+        document->new_page(page_num, t_page); //problem here
+      } else {
+        document->new_page(page_num);
+      }
+      
+      // go to the new page
+      document_view.set_current_page_num(page_num);
     }
-    break;
-  default: // assume anything else means CANCEL
-    break;
   }
   hide();
 }
