@@ -2,14 +2,13 @@
 // Copyright (C) 2003, 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "dialogwrap.h"
-#include "wmisc.h"
 
-DialogWrap::DialogWrap(const std::string& name)
+DialogWrap::DialogWrap(const Glib::ustring& name)
   : Gtk::Dialog(name + " - Passepartout",
 		false /* modal */, false /* separator */)
 {}
 
-DialogWrap::DialogWrap(const std::string& name, Gtk::Window& parent)
+DialogWrap::DialogWrap(const Glib::ustring& name, Gtk::Window& parent)
   : Gtk::Dialog(name + " - Passepartout",
 		parent, true /* modal */, false /* separator */)
 {}
@@ -30,3 +29,13 @@ Gtk::Button* DialogWrap::fix_button(Gtk::Button* button, int action_id) {
 				    action_id));
   return b;
 }
+
+UtilityWindow::UtilityWindow(const Glib::ustring& name) {
+  set_title(name + " - Passepartout");
+}
+
+void UtilityWindow::show_raise() {
+  Glib::RefPtr<Gdk::Window> win = get_window();
+  win->show();			// uniconify if necessary
+  win->raise();			// raise if necessary
+}
