@@ -1,23 +1,24 @@
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "filesys.h"
 #include "stringutil.h"
 #include "os.h"
+#include <errno.h>
+#include <memory>
 #include <unistd.h>
 #include <stdexcept>
+#include "defines.h"
+#include <sys/stat.h>
+#ifndef HAVE_MKDTEMP
+#include <sys/types.h>
+#endif
 
 using std::string;
 
-/**
- * An exception to use when a libc call fails and sets errno.
- */
-class ClibException : public std::runtime_error {
-public:
-  explicit ClibException(const string& msg)
-    : runtime_error(msg + ": " + strerror(errno))
-    {}
-};
+ClibException::ClibException(const string& msg)
+  : runtime_error(msg + ": " + strerror(errno))
+{}
 
 bool exists(const string& filename) {
   return access(filename.c_str(), F_OK) == 0;
@@ -31,6 +32,14 @@ bool access(const string& filename, int mode) {
   return result == 0;
 }
 
+time_t modified(const std::string& filename) {
+  struct stat buf;
+  if(stat(filename.c_str(), &buf) == 0) // returns 0 on success, -1 otherwise
+    return buf.st_mtime;
+  else
+    throw ClibException("Failed to stat(2) \"" + filename + '"');
+}
+
 string suffix(const string& filename) {
   const string::size_type pos = filename.find_last_of('.');
   if(pos == string::npos)
@@ -76,7 +85,7 @@ string expand_path(const string& filename) {
   if(realpath(filename.empty()?".":filename.c_str(), resolved_path.get()))
     return resolved_path.get();
   else
-    throw ClibException("Failed to resolve " + filename);
+    throw ClibException("Failed to resolve \"" + filename + '"');
 }
 
 string relative_path(const string& start_path, const string& filename)
@@ -91,12 +100,12 @@ string relative_path(const string& start_path, const string& filename)
 
 void unlink(const std::string& filename) {
   if(::unlink(filename.c_str()) != 0)
-    throw ClibException("Failed to unlink " + filename);
+    throw ClibException("Failed to unlink \"" + filename + '"');
 }
 
 void rmdir(const std::string& dirname) {
   if(::rmdir(dirname.c_str()) != 0)
-    throw ClibException("Failed to rmdir " + dirname);
+    throw ClibException("Failed to rmdir \"" + dirname + '"');
 }
 
 std::string mkdtemp(const std::string& tmpl_name) {
@@ -116,8 +125,22 @@ std::string mkdtemp(const std::string& tmpl_name) {
     else
       name = tmpdir + '/' + tmpl_name;
   }
+#ifdef HAVE_MKDTEMP
   char* actual = ::mkdtemp(strcpy(new char[name.length()+1], name.c_str()));
-  string result = actual;
-  delete actual;
+  const string result = actual;
+  delete[] actual;
+  
+#else
+#warning Using workaround for lack of mkdtemp.  Probably buggy.
+  // This is seriously bad: Not only is there a possible race condition, the
+  // man page for mktemp on solaris states that "Only 26 unique file names per
+  // thread can be created for each unique template".
+  char *actual = ::mktemp(strcpy(new char[name.length()+1], name.c_str()));
+  const string result = actual;
+  if(::mkdir(actual, 0700) != 0)
+    throw ClibException("Failed to mkdir \"" + result + "\"");
+  delete[] actual;
+  
+#endif
   return result;
 }
